Trait that can be used when working with Solana structs that are used as accounts.
Modules
Macros
- impl_
int_ conversion - Simple macro for implementing conversion functions between Pod* ints and standard ints.
Trait that can be used when working with Solana structs that are used as accounts.